# reference output definition
OF.refWaterLevel = read.csv(file=paste(OF.dirBase,"measured-level.csv",sep=""),header=TRUE,sep=" ",stringsAsFactors=F)
OF.refWaterLevel$datetime = as.POSIXct(OF.refWaterLevel$datetime,format="%Y-%m-%dT%H:%M:%S",tz="UTC")
  
pdf(paste(OF.dirBase,"R-MHYDAS-measured-level.pdf",sep=""))
plot(OF.refWaterLevel,xlab='Date',ylab='Water level [m]')
dev.off()

# run optimization process
OF.parInit = c(0.01,0.2)
OF.factorsOptim=optim(par=OF.parInit,fn=OF.singleRun,method='L-BFGS-B',lower=0.1*OF.parInit,upper=5.0*OF.parInit,ref=OF.refWaterLevel)

pdf(paste(OF.dirBase,"R-MHYDAS-optimized-level.pdf",sep=""))
# plot water level with initial parameters
OpenFLUID.setSimulatorParam(OF.simu,"water.surf.transfer-rs.hayami","meancel",OF.parInit[1])
OpenFLUID.setAttribute(OF.simu,"RS",3,"width",OF.parInit[2])
OpenFLUID.addVariablesExportAsCSV(OF.simu,'RS')
OpenFLUID.runSimulation(OF.simu)
OF.initWaterLevel = OpenFLUID.loadResult(OF.simu,"RS",3,"water.surf.H.level-rs")
plot(OF.initWaterLevel,type='l',lwd=2,xlab='Date',ylab='Water level [m]')

# plot water level with optimal parameters
OpenFLUID.setSimulatorParam(OF.simu,"water.surf.transfer-rs.hayami","meancel",OF.factorsOptim$par[1])
OpenFLUID.setAttribute(OF.simu,"RS",3,"width",OF.factorsOptim$par[2])
OpenFLUID.addVariablesExportAsCSV(OF.simu,'RS')
OpenFLUID.runSimulation(OF.simu)
OF.optimWaterLevel = OpenFLUID.loadResult(OF.simu,"RS",3,"water.surf.H.level-rs")
lines(OF.optimWaterLevel,col='red',lwd=2)

points(OF.refWaterLevel,col='blue')
legend("topright",c('Initial parameters','Optimized parameters','Measured'),lty=c(1,1,3),lwd=c(2,2,2),col=c('black','red','blue'))
print(OF.factorsOptim$par)
dev.off()
